#!/usr/bin/env bash

setup_file(){
  load "$PWD/tests/integration/helpers/common"
  _common_setup
  _add_server
  _new_app
}

teardown_file(){
  _rm_app
  _rm_server
}

setup(){
  load "$PWD/tests/integration/helpers/common"
  _common_setup
}

teardown(){
  # https://github.com/bats-core/bats-core/issues/383#issuecomment-738628888
  if [[ -z "${BATS_TEST_COMPLETED}" ]]; then
    _undeploy_app
  fi
}

@test "validate app argument" {
  run $ABRA app undeploy
  assert_failure
  assert_output --partial 'no app provided'

  run $ABRA app undeploy DOESNTEXIST
  assert_failure
  assert_output --partial 'cannot find app'
}

@test "error if not deployed" {
  run $ABRA app undeploy "$TEST_APP_DOMAIN"
  assert_failure
  assert_output --partial 'is not deployed'
}

# bats test_tags=slow
@test "undeploy app" {
  _deploy_app
  _undeploy_app
}

# bats test_tags=slow
@test "undeploy and prune" {
  _deploy_app

  run $ABRA app undeploy "$TEST_APP_DOMAIN" --no-input --prune
  assert_success
}
